@@ -374,10 +374,10 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##' [base::strptime()] whenever the guessed from the input data formats are all
 ##' numeric.
 ##'
-##' The list below contains formats recognized by \pkg{lubridate}. For numeric formats
-##' leading 0s are optional. As compared to [base::strptime()], some of the
-##' formats are new or have been extended for efficiency reasons. These formats
-##' are marked with "(*)". The fast parsers `parse_date_time2()` and
+##' The list below contains formats recognized by \pkg{lubridate}. For numeric
+##' formats leading 0s are optional. As compared to [base::strptime()], some of
+##' the formats are new or have been extended for efficiency reasons. These
+##' formats are marked with "(*)" below. Fast parsers `parse_date_time2()` and
 ##' `fast_strptime()` accept only formats marked with "(!)".
 ##'
 ##'
@@ -403,22 +403,19 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##'
 ##' \item{`j`}{Day of year as decimal number (001--366 or 1--366).}
 ##'
-##' \item{`q` (!*)}{Quarter (1--4). The quarter month is added to the parsed month
-##' if `m` format is present.}
+##' \item{`q` (!*)}{Quarter (1--4). The quarter month is added to the parsed
+##'   month if `m` element is present.}
 ##'
 ##' \item{`m` (!*)}{Month as decimal number (01--12 or 1--12). For
-##'                   `parse_date_time`. As a \pkg{lubridate} extension, also
-##'                   matches abbreviated and full months names as `b` and
-##'                   `B` formats. C parser understands only English month
-##'                   names.}
+##'   `parse_date_time` also matches abbreviated and full months names as `b`
+##'   and `B` formats. C parser understands only English month names.}
 ##'
 ##' \item{`M` (!)}{Minute as decimal number (00--59 or 0--59).}
 ##'
-##' \item{`p` (!)}{AM/PM indicator in the locale. Normally used in conjunction
-##'                   with `I` and \bold{not} with `H`.  But the \pkg{lubridate}
-##'                   C parser accepts H format as long as hour is not greater
-##'                   than 12. C parser understands only English locale AM/PM
-##'                   indicator.}
+##' \item{`p` (!)}{AM/PM indicator in the locale. Commonly used in conjunction
+##'  with `I` and \bold{not} with `H`.  But \pkg{lubridate}'s C parser accepts H
+##'  format as long as hour is not greater than 12. C parser understands only
+##'  English locale AM/PM indicator.}
 ##'
 ##' \item{`S` (!)}{Second as decimal number (00--61 or 0--61), allowing for up
 ##' to two leap-seconds (but POSIX-compliant implementations will ignore leap
@@ -442,13 +439,12 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##' \item{`Y` (!)}{Year with century.}
 ##'
 ##' \item{`z` (!*)}{ISO8601 signed offset in hours and minutes from UTC. For
-##' example `-0800`, `-08:00` or `-08`, all represent 8 hours
-##' behind UTC. This format also matches the Z (Zulu) UTC indicator. Because
-##' [base::strptime()] doesn't fully support ISO8601 this format is implemented as an
-##' union of 4 orders: Ou (Z), Oz (-0800), OO (-08:00) and Oo (-08). You can use
-##' these four orders as any other but it is rarely
-##' necessary. `parse_date_time2()` and `fast_strptime()` support all of
-##' the timezone formats.}
+##' example `-0800`, `-08:00` or `-08`, all represent 8 hours behind UTC. This
+##' format also matches the Z (Zulu) UTC indicator. Because [base::strptime()]
+##' doesn't fully support ISO8601 this format is implemented as an union of 4
+##' formats: Ou (Z), Oz (-0800), OO (-08:00) and Oo (-08). You can use these
+##' formats as any other but it is rarely necessary. `parse_date_time2()` and
+##' `fast_strptime()` support all of these formats.}
 ##'
 ##' \item{`Om` (!*)}{Matches numeric month and English alphabetic months
 ##'                    (Both, long and abbreviated forms).}
@@ -465,12 +461,14 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##'
 ##' @export
 ##' @param x a character or numeric vector of dates
-##' @param orders a character vector of date-time formats. Each order string is a
-##'   series of formatting characters as listed in [base::strptime()] but might not
-##'   include the `"%"` prefix. For example, "ymd" will match all the possible
-##'   dates in year, month, day order. Formatting orders might include
-##'   arbitrary separators. These are discarded. See details for implemented
-##'   formats.
+##' @param orders a character vector of date-time formats. Each order string is
+##'   a series of formatting characters as listed in [base::strptime()] but
+##'   might not include the `"%"` prefix. For example, "ymd" will match all the
+##'   possible dates in year, month, day order. Formatting orders might include
+##'   arbitrary separators. These are discarded. See details for the implemented
+##'   formats. If multiple order strings are supplied, they are applied in turn
+##'   for `parse_date_time2()` and `fast_strptime()`. For `parse_date_time()`
+##'   the order of applied formats is determined by `select_formats` parameter.
 ##' @param tz a character string that specifies the time zone with which to
 ##'   parse the dates
 ##' @param truncated integer, number of formats that can be missing. The most
@@ -479,13 +477,13 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##'   is non-zero `parse_date_time()` also checks for truncated formats. For
 ##'   example,  if the format order is "ymdHMS" and `truncated = 3`,
 ##'   `parse_date_time()` will correctly parse incomplete date-times like
-##'   `2012-06-01 12:23`, `2012-06-01 12` and `2012-06-01`. \bold{NOTE:} The `ymd()`
-##'   family of functions is based on [base::strptime()] which currently fails to parse
-##'   `%Y-%m` formats.
-##' @param quiet logical. If `TRUE`, progress messages are not printed, and
-##'   `No formats found` error is suppressed and the function simply returns a
-##'   vector of NAs.  This mirrors the behavior of base R functions [base::strptime()]
-##'   and [base::as.POSIXct()].
+##'   `2012-06-01 12:23`, `2012-06-01 12` and `2012-06-01`. \bold{NOTE:} The
+##'   `ymd()` family of functions is based on [base::strptime()] which currently
+##'   fails to parse `%Y-%m` formats.
+##' @param quiet logical. If `TRUE`, progress messages are not printed, and `No
+##'   formats found` error is suppressed and the function simply returns a
+##'   vector of NAs.  This mirrors the behavior of base R functions
+##'   [base::strptime()] and [base::as.POSIXct()].
 ##' @param locale locale to be used, see \link{locales}. On Linux systems you
 ##'   can use `system("locale -a")` to list all the installed locales.
 ##' @param select_formats A function to select actual formats for parsing from a
@@ -501,30 +499,32 @@ hms <- function(..., quiet = FALSE, roll = FALSE) {
 ##' @param exact logical. If `TRUE`, the `orders` parameter is interpreted as an
 ##'   exact [base::strptime()] format and no training or guessing are performed
 ##'   (i.e. `train`, `drop` parameters are irrelevant).
-##' @param train logical, default `TRUE`. Whether to train formats on a subset of
-##'   the input vector. The result of this is that supplied orders are sorted
+##' @param train logical, default `TRUE`. Whether to train formats on a subset
+##'   of the input vector. The result of this is that supplied orders are sorted
 ##'   according to performance on this training set, which commonly results in
 ##'   increased performance. Please note that even when `train = FALSE` (and
 ##'   `exact = FALSE`) guessing of the actual formats is still performed on a
 ##'   pseudo-random subset of the original input vector. This might result in
 ##'   `All formats failed to parse` error. See notes below.
 ##' @param drop logical, default `FALSE`. Whether to drop formats that didn't
-##'   match on the training set. If `FALSE`, unmatched on the training set formats
-##'   are tried as a last resort at the end of the parsing queue. Applies only
-##'   when `train = TRUE`. Setting this parameter to `TRUE` might slightly speed up
-##'   parsing in situations involving many formats. Prior to v1.7.0 this
-##'   parameter was implicitly `TRUE`, which resulted in occasional surprising
-##'   behavior when rare patterns where not present in the training set.
+##'   match on the training set. If `FALSE`, unmatched on the training set
+##'   formats are tried as a last resort at the end of the parsing
+##'   queue. Applies only when `train = TRUE`. Setting this parameter to `TRUE`
+##'   might slightly speed up parsing in situations involving many
+##'   formats. Prior to v1.7.0 this parameter was implicitly `TRUE`, which
+##'   resulted in occasional surprising behavior when rare patterns where not
+##'   present in the training set.
 ##' @return a vector of POSIXct date-time objects
 ##' @seealso [base::strptime()], [ymd()], [ymd_hms()]
 ##' @keywords chron
 ##' @note `parse_date_time()` (and the derivatives `ymd()`, `ymd_hms()`, etc.)
-##'   relies on a sparse guesser that takes at most 501 elements from the supplied
-##'   character vector in order to identify appropriate formats from the
-##'   supplied orders. If you get the error `All formats failed to parse` and
-##'   you are confident that your vector contains valid dates, you should either
-##'   set `exact` argument to `TRUE` or use functions that don't perform format
-##'   guessing (`fast_strptime()`, `parse_date_time2()` or [base::strptime()]).
+##'   relies on a sparse guesser that takes at most 501 elements from the
+##'   supplied character vector in order to identify appropriate formats from
+##'   the supplied orders. If you get the error `All formats failed to parse`
+##'   and you are confident that your vector contains valid dates, you should
+##'   either set `exact` argument to `TRUE` or use functions that don't perform
+##'   format guessing (`fast_strptime()`, `parse_date_time2()` or
+##'   [base::strptime()]).
 ##' @note For performance reasons, when timezone is not UTC,
 ##'   `parse_date_time2()` and `fast_strptime()` perform no validity checks for
 ##'   daylight savings time. Thus, if your input string contains an invalid date
@@ -665,58 +665,69 @@ parse_dt <- function(x, orders, is_format = FALSE, return_lt = FALSE, cutoff_200
   .Call(C_parse_dt, x, orders, as.logical(is_format), as.logical(return_lt), as.integer(cutoff_2000))
 }
 
-##' @description
-##' `parse_date_time2()` is a fast C parser of numeric
-##' orders.
+##' @description `parse_date_time2()` is a fast C parser of numeric orders.
 ##'
 ##' @rdname parse_date_time
 ##' @export
 ##' @param lt logical. If `TRUE`, returned object is of class POSIXlt, and POSIXct
 ##'   otherwise. For compatibility with [base::strptime()] the default is `TRUE`
 ##'   for `fast_strptime()` and `FALSE` for `parse_date_time2()`.
-##' @param cutoff_2000 integer. For `y` format,  two-digit numbers smaller or equal to
-##'   `cutoff_2000` are parsed as 20th's century, 19th's otherwise. Available only
-##'   for functions relying on `lubridate`s internal parser.
+##' @param cutoff_2000 integer. For `y` format,  two-digit numbers smaller or equal
+##'    to `cutoff_2000` are parsed as though starting with `20`, otherwise parsed
+##'    as though starting with `19`. Available only for functions relying on
+##'    `lubridate`s internal parser.
 parse_date_time2 <- function(x, orders, tz = "UTC", exact = FALSE, lt = FALSE, cutoff_2000 = 68L){
   if (length(tz) != 1 || is.na(tz))
     stop("`tz` argument must be a character of length one")
-  if (length(orders) > 1)
-    warning("Multiple orders supplied. Only first order is used.")
-  if (!exact)
-    orders <- gsub("[^[:alpha:]]+", "", as.character(orders[[1]])) ## remove all separators
-  if (lt) {
-    .mklt(parse_dt(x, orders, exact, TRUE, cutoff_2000), tz)
-  } else {
-    if (is_utc(tz)){
-      .POSIXct(parse_dt(x, orders, exact, FALSE, cutoff_2000), tz = "UTC")
+  parse1 <- function(x, order) {
+    if (!exact)
+      order <- gsub("[^[:alpha:]]+", "", as.character(order))
+    if (lt) {
+      .mklt(parse_dt(x, order, exact, TRUE, cutoff_2000), tz)
     } else {
-      as.POSIXct(.mklt(parse_dt(x, orders, exact, TRUE, cutoff_2000), tz))
+      if (is_utc(tz)) {
+        .POSIXct(parse_dt(x, order, exact, FALSE, cutoff_2000), tz = "UTC")
+      } else {
+        as.POSIXct(.mklt(parse_dt(x, order, exact, TRUE, cutoff_2000), tz))
+      }
     }
   }
+  nnas <- !is.na(x)
+  out <- parse1(x, orders[[1]])
+  for (order in orders[-1]) {
+    nnas <- nnas & is.na(out)
+    out[nnas] <- parse1(x[nnas], order)
+  }
+  out
 }
 
-##' @description
-##' `fast_strptime()` is a fast C parser of numeric formats only
-##' that accepts explicit format arguments, just like
-##' [base::strptime()].
+##' @description `fast_strptime()` is a fast C parser of numeric formats only
+##'   that accepts explicit format arguments, just like [base::strptime()].
 ##' @rdname parse_date_time
 ##' @export
-##' @param format a character string of formats. It should include all the
-##'   separators and each format must be prefixed with %, just as in the format
-##'   argument of [base::strptime()].
+##' @param format a vector of formats. If multiple formats supplied they are
+##'   applied in turn till success. The formats should include all the
+##'   separators and each format letter must be prefixed with %, just as in the
+##'   format argument of [base::strptime()].
 fast_strptime <- function(x, format, tz = "UTC", lt = TRUE, cutoff_2000 = 68L) {
-  if (length(format) > 1)
-    warning("Multiple formats supplied. Only first format is used.")
-  format <- as.character(format[[1]])
-  if (lt) {
-    .mklt(parse_dt(x, format, TRUE, TRUE, cutoff_2000), tz)
-  } else{
-    if (is_utc(tz)) {
-      .POSIXct(parse_dt(x, format, TRUE, FALSE, cutoff_2000), "UTC")
-    } else {
-      as.POSIXct(.mklt(parse_dt(x, format, TRUE, TRUE, cutoff_2000), tz))
+  parse1 <- function(x, fmt) {
+    if (lt) {
+      .mklt(parse_dt(x, fmt, TRUE, TRUE, cutoff_2000), tz)
+    } else{
+      if (is_utc(tz)) {
+        .POSIXct(parse_dt(x, fmt, TRUE, FALSE, cutoff_2000), "UTC")
+      } else {
+        as.POSIXct(.mklt(parse_dt(x, fmt, TRUE, TRUE, cutoff_2000), tz))
+      }
     }
   }
+  nnas <- !is.na(x)
+  out <- parse1(x, format[[1]])
+  for (fmt in format[-1]) {
+    nnas <- nnas & is.na(out)
+    out[nnas] <- parse1(x[nnas], fmt)
+  }
+  out
 }
 
 
